# -*- coding: utf-8 -*-
#
#       ramstk.models.dbviews.baseview.py is part of The RAMSTK Project
#
# All rights reserved.
# Copyright since 2007 Doyle "weibullguy" Rowland doyle.rowland <AT> reliaqual <DOT> com
"""Metaclass for the database view models."""

# Standard Library Imports
from typing import Callable, Dict, List, Union

# Third Party Imports
import treelib
from pubsub import pub

# RAMSTK Package Imports
from ramstk.models.db import BaseDatabase


class RAMSTKBaseView:
    """Metaclass for all RAMSTK View models.

    :cvar _root: the Node ID number for the treelib.Tree.
    :cvar _tag: the name of the RAMSTK work flow module.  This is the same for all
        classes associated with the work flow module.

    :ivar _dic_load_functions: a dict of functions to call for loading a row of data
        in the view's RAMSTKTreeView.
    :ivar _dic_trees: a dict of treelib.Tree, one for each database table the view is
        comprised from.
    :ivar _lst_modules: the list of RAMSTK work flow modules that comprise the view.
    :ivar _revision_id: the ID of the Revision the view is associated with.
    :ivar dao: the instanace of the RAMSTK Program database model.
    :ivar tree: the view's treelib.Tree.  This is a conblomerate of the trees in
        _dic_trees.
    """

    # Define private dictionary class attributes.

    # Define private list class attributes.

    # Define private scalar class attributes.
    _root: int = 0
    _tag: str = ""

    # Define public dictionary class attributes.

    # Define public list class attributes.

    # Define public scalar class attributes.

    # pylint: disable=unused-argument
    # noinspection PyUnusedLocal
    def __init__(self, **kwargs: Dict[str, Union[float, int, str]]) -> None:
        """Initialize a RAMSTK view model instance."""

        # Initialize private dictionary attributes.
        self._dic_load_functions: Dict[str, Callable[..., object]] = {}
        self._dic_trees: Dict[str, treelib.Tree] = {}

        # Initialize private list attributes.
        self._lst_modules: List[str] = []

        # Initialize private scalar attributes.
        self._revision_id: int = 0

        # Initialize public dictionary attributes.

        # Initialize public list attributes.

        # Initialize public scalar attributes.
        self.dao: BaseDatabase = BaseDatabase()
        self.tree: treelib.Tree = treelib.Tree()

        # Add the root to the Tree().  This is necessary to allow multiple
        # entries at the top level as there can only be one root in a treelib
        # Tree().  Manipulation and viewing of a RAMSTK module tree needs to
        # ignore the root of the tree.
        self.tree.create_node(tag=self._tag, identifier=self._root)

        # Subscribe to PyPubSub messages.

    def do_set_tree(self, tree: treelib.Tree) -> None:
        """Assign the treelib Tree() for the constituent module.

        :param tree: the calling module's treelib Tree().
        :return: None
        :rtype: None
        """
        self._dic_trees[tree.get_node(0).tag] = tree
        self.on_select_all()

    def on_select_all(self) -> None:
        """Build the usage profile treelib Tree().

        This method builds the hierarchical treelib Tree() from the individual
        module trees.

        :return: None
        :rtype: None
        """
        for _node in self.tree.children(self.tree.root):
            self.tree.remove_node(_node.identifier)

        if self._dic_trees[self._lst_modules[0]].depth() > 0:
            self._dic_load_functions[self._lst_modules[0]]()

            pub.sendMessage(
                f"succeed_retrieve_{self._tag}",
                tree=self.tree,
            )



# -*- coding: utf-8 -*-
#
#       ramstk.models.dbrecords.commondb_group_record.py is part of The RAMSTK Project
#
# All rights reserved.
# Copyright since 2007 Doyle "weibullguy" Rowland doyle.rowland <AT> reliaqual <DOT> com
"""Group Record Model."""

# Third Party Imports
from sqlalchemy import Column, Integer, String

# RAMSTK Local Imports
from .. import RAMSTK_BASE
from .baserecord import RAMSTKBaseRecord


class RAMSTKGroupRecord(RAMSTK_BASE, RAMSTKBaseRecord):  # type: ignore
    """Class to represent the table ramstk_group in the RAMSTK Common database.

    This table shares a Many-to-One relationship with ramstk_user.
    """

    __defaults__ = {
        "description": "Group Description",
        "group_type": "",
    }
    __tablename__ = "ramstk_group"
    __table_args__ = {"extend_existing": True}

    group_id = Column(
        "fld_group_id",
        Integer,
        primary_key=True,
        autoincrement=True,
        nullable=False,
    )
    description = Column(
        "fld_description", String(512), default=__defaults__["description"]
    )
    group_type = Column(
        "fld_group_type", String(256), default=__defaults__["group_type"]
    )

    def get_attributes(self):
        """Retrieve current values of the RAMSTKGroup data model attributes.

        :return: {workgroup_id, description, group_type} pairs
        :rtype: dict
        """
        return {
            "group_id": self.group_id,
            "description": self.description,
            "group_type": self.group_type,
        }



# Standard Library Imports
from datetime import date
from typing import Dict, List, Type, Union

# RAMSTK Local Imports
from ..dbrecords import RAMSTKFailureDefinitionRecord as RAMSTKFailureDefinitionRecord
from .basetable import RAMSTKBaseTable as RAMSTKBaseTable

class RAMSTKFailureDefinitionTable(RAMSTKBaseTable):
    _db_id_colname: str
    _db_tablename: str
    _select_msg: str
    _tag: str
    _lst_id_columns: List[str]
    _record: Type[RAMSTKFailureDefinitionRecord]
    pkey: str
    def __init__(self, **kwargs: Dict[str, Union[float, int, str]]) -> None: ...
    def do_get_new_record(
        self, attributes: Dict[str, Union[date, float, int, str]]
    ) -> RAMSTKFailureDefinitionRecord: ...



# pylint: disable=unused-import
# -*- coding: utf-8 -*-
#
#       ramstk.models.dbrecords.__init__.py is part of The RAMSTK Project
#
# All rights reserved.
# Copyright since 2007 Doyle "weibullguy" Rowland doyle.rowland <AT> reliaqual <DOT> com
"""The RAMSTK database record models package."""

# RAMSTK Local Imports
from .commondb_category_record import RAMSTKCategoryRecord
from .commondb_condition_record import RAMSTKConditionRecord
from .commondb_failure_mode_record import RAMSTKFailureModeRecord
from .commondb_group_record import RAMSTKGroupRecord
from .commondb_hazards_record import RAMSTKHazardsRecord
from .commondb_load_history_record import RAMSTKLoadHistoryRecord
from .commondb_manufacturer_record import RAMSTKManufacturerRecord
from .commondb_measurement_record import RAMSTKMeasurementRecord
from .commondb_method_record import RAMSTKMethodRecord
from .commondb_model_record import RAMSTKModelRecord
from .commondb_rpn_record import RAMSTKRPNRecord
from .commondb_site_info_record import RAMSTKSiteInfoRecord
from .commondb_stakeholders_record import RAMSTKStakeholdersRecord
from .commondb_status_record import RAMSTKStatusRecord
from .commondb_subcategory_record import RAMSTKSubCategoryRecord
from .commondb_type_record import RAMSTKTypeRecord
from .commondb_user_record import RAMSTKUserRecord
from .programdb_action_record import RAMSTKActionRecord
from .programdb_allocation_record import RAMSTKAllocationRecord
from .programdb_cause_record import RAMSTKCauseRecord
from .programdb_control_record import RAMSTKControlRecord
from .programdb_design_electric_record import RAMSTKDesignElectricRecord
from .programdb_design_mechanic_record import RAMSTKDesignMechanicRecord
from .programdb_environment_record import RAMSTKEnvironmentRecord
from .programdb_failure_definition_record import RAMSTKFailureDefinitionRecord
from .programdb_function_record import RAMSTKFunctionRecord
from .programdb_hardware_record import RAMSTKHardwareRecord
from .programdb_hazard_record import RAMSTKHazardRecord
from .programdb_mechanism_record import RAMSTKMechanismRecord
from .programdb_milhdbk217f_record import RAMSTKMilHdbk217FRecord
from .programdb_mission_phase_record import RAMSTKMissionPhaseRecord
from .programdb_mission_record import RAMSTKMissionRecord
from .programdb_mode_record import RAMSTKModeRecord
from .programdb_nswc_record import RAMSTKNSWCRecord
from .programdb_opload_record import RAMSTKOpLoadRecord
from .programdb_opstress_record import RAMSTKOpStressRecord
from .programdb_program_info_record import RAMSTKProgramInfoRecord
from .programdb_program_status_record import RAMSTKProgramStatusRecord
from .programdb_reliability_record import RAMSTKReliabilityRecord
from .programdb_requirement_record import RAMSTKRequirementRecord
from .programdb_revision_record import RAMSTKRevisionRecord
from .programdb_similar_item_record import RAMSTKSimilarItemRecord
from .programdb_stakeholder_record import RAMSTKStakeholderRecord
from .programdb_test_method_record import RAMSTKTestMethodRecord
from .programdb_validation_record import RAMSTKValidationRecord



# pylint: disable=unused-import
# -*- coding: utf-8 -*-
#
#       ramstk.models.dbviews.__init__.py is part of The RAMSTK Project
#
# All rights reserved.
# Copyright since 2007 Doyle "weibullguy" Rowland doyle.rowland <AT> reliaqual <DOT> com
"""The RAMSTK database view models package."""

# RAMSTK Local Imports
from .programdb_fmea_view import RAMSTKFMEAView
from .programdb_hardware_view import RAMSTKHardwareBoMView
from .programdb_pof_view import RAMSTKPoFView
from .programdb_usage_profile_view import RAMSTKUsageProfileView



# pylint: disable=unused-import
# -*- coding: utf-8 -*-
#
#       ramstk.models.__init__.py is part of The RAMSTK Project
#
# All rights reserved.
# Copyright since 2007 Doyle "weibullguy" Rowland doyle.rowland <AT> reliaqual <DOT> com
"""The RAMSTK database models package."""

# Third Party Imports
from sqlalchemy.ext.declarative import declarative_base

RAMSTK_BASE = declarative_base()



# Standard Library Imports
from typing import Any, Dict, List

# RAMSTK Package Imports
from ramstk.views.gtk3 import _ as _
from ramstk.views.gtk3.widgets import RAMSTKComboBox as RAMSTKComboBox
from ramstk.views.gtk3.widgets import RAMSTKEntry as RAMSTKEntry
from ramstk.views.gtk3.widgets import RAMSTKFixedPanel as RAMSTKFixedPanel

class SemiconductorDesignElectricInputPanel(RAMSTKFixedPanel):
    _dic_quality: Dict[int, List[List[str]]]
    _dic_types: Dict[int, List[List[str]]]
    _dic_applications: Dict[int, List[List[str]]]
    _dic_matchings: Dict[int, List[List[str]]]
    _lst_packages: List[List[str]]
    _record_field: str
    _select_msg: str
    _tag: str
    _title: str
    cmbApplication: RAMSTKComboBox
    cmbConstruction: RAMSTKComboBox
    cmbMatching: RAMSTKComboBox
    cmbPackage: RAMSTKComboBox
    cmbQuality: RAMSTKComboBox
    cmbType: RAMSTKComboBox
    txtFrequencyOperating: RAMSTKEntry
    txtNElements: RAMSTKEntry
    txtThetaJC: RAMSTKEntry
    _hazard_rate_method_id: int
    _quality_id: int
    dic_attribute_widget_map: Dict[str, List[Any]]
    category_id: int
    subcategory_id: int
    def __init__(self) -> None: ...
    def do_load_comboboxes(self, subcategory_id: int) -> None: ...
    def _do_set_reliability_attributes(self, attributes: Dict[str, Any]) -> None: ...
    def _do_set_sensitive(self) -> None: ...
    def __do_load_application(self) -> None: ...
    def __do_load_construction(self) -> None: ...
    def __do_load_matching(self) -> None: ...
    def __do_load_quality(self) -> None: ...
    def __do_load_type(self) -> None: ...
    def __do_set_application_sensitive(self) -> None: ...
    def __do_set_construction_sensitive(self) -> None: ...
    def __do_set_elements_sensitive(self) -> None: ...
    def __do_set_matching_sensitive(self) -> None: ...
    def __do_set_op_freq_sensitive(self) -> None: ...
    def __do_set_type_sensitive(self) -> None: ...



# Standard Library Imports
from datetime import date
from typing import Dict, List, Type, Union

# Third Party Imports
import treelib

# RAMSTK Package Imports
from ramstk.analyses import similaritem as similaritem
from ramstk.views.gtk3 import _ as _

# RAMSTK Local Imports
from ..dbrecords import RAMSTKSimilarItemRecord as RAMSTKSimilarItemRecord
from .basetable import RAMSTKBaseTable as RAMSTKBaseTable

class RAMSTKSimilarItemTable(RAMSTKBaseTable):
    _db_id_colname: str
    _db_tablename: str
    _select_msg: str
    _tag: str
    _lst_id_columns: List[str]
    _node_hazard_rate: float
    _record: Type[RAMSTKSimilarItemRecord]
    pkey: str
    def __init__(self, **kwargs: Dict[str, Union[float, int, str]]) -> None: ...
    _parent_id: int
    def do_get_new_record(
        self, attributes: Dict[str, Union[date, float, int, str]]
    ) -> RAMSTKSimilarItemRecord: ...
    def do_calculate_similar_item(self, node_id: int) -> None: ...
    def do_roll_up_change_descriptions(self, node_id: int) -> None: ...
    def _do_calculate_topic_633(self, node_id: int) -> None: ...
    def _do_calculate_user_defined(self, node_id: int) -> None: ...
    def _on_insert_hardware(self, tree: treelib.Tree) -> None: ...



# -*- coding: utf-8 -*-
from setuptools import setup

package_dir = \
{'': 'src'}

packages = \
['ramstk',
 'ramstk.analyses',
 'ramstk.analyses.milhdbk217f',
 'ramstk.analyses.milhdbk217f.models',
 'ramstk.analyses.statistics',
 'ramstk.exim',
 'ramstk.models',
 'ramstk.models.db',
 'ramstk.models.dbrecords',
 'ramstk.models.dbtables',
 'ramstk.models.dbviews',
 'ramstk.views',
 'ramstk.views.gtk3',
 'ramstk.views.gtk3.allocation',
 'ramstk.views.gtk3.assistants',
 'ramstk.views.gtk3.books',
 'ramstk.views.gtk3.design_electric',
 'ramstk.views.gtk3.design_electric.components',
 'ramstk.views.gtk3.failure_definition',
 'ramstk.views.gtk3.fmea',
 'ramstk.views.gtk3.function',
 'ramstk.views.gtk3.hardware',
 'ramstk.views.gtk3.hazard_analysis',
 'ramstk.views.gtk3.milhdbk217f',
 'ramstk.views.gtk3.milhdbk217f.components',
 'ramstk.views.gtk3.options',
 'ramstk.views.gtk3.pof',
 'ramstk.views.gtk3.preferences',
 'ramstk.views.gtk3.program_status',
 'ramstk.views.gtk3.reliability',
 'ramstk.views.gtk3.requirement',
 'ramstk.views.gtk3.revision',
 'ramstk.views.gtk3.similar_item',
 'ramstk.views.gtk3.stakeholder',
 'ramstk.views.gtk3.usage_profile',
 'ramstk.views.gtk3.validation',
 'ramstk.views.gtk3.widgets']

package_data = \
{'': ['*']}

install_requires = \
['XlsxWriter>=3.0.1,<4.0.0',
 'lifelines>=0.26.3,<0.27.0',
 'matplotlib>=3.3.4,<4.0.0',
 'openpyxl>=3.0.6,<4.0.0',
 'pandas==1.1.5',
 'psycopg2>=2.8.6,<3.0.0',
 'pycairo>=1.20.0,<2.0.0',
 'pygobject>=3.38,<4.0',
 'pypubsub>=4.0.3,<5.0.0',
 'sortedcontainers>=2.3.0,<3.0.0',
 'sqlalchemy-utils>=0.38.0,<0.39.0',
 'sqlalchemy>=1.3.0,<2.0.0',
 'statsmodels>=0.12.2,<0.13.0',
 'sympy>=1.8.0,<2.0.0',
 'toml>=0.10.2,<0.11.0',
 'treelib>=1.5.3,<2.0.0',
 'xlrd>=2.0.1,<3.0.0',
 'xlwt>=1.3.0,<2.0.0']

extras_require = \
{':python_version >= "3.6" and python_version < "3.7"': ['numpy>=1.19,<2.0',
                                                         'scipy>=1.5,<2.0'],
 ':python_version >= "3.7" and python_version < "4.0"': ['numpy>=1.21,<2.0',
                                                         'scipy>=1.6.0,<2.0.0']}

entry_points = \
{'console_scripts': ['ramstk = ramstk.__main__:the_one_ring']}

setup_kwargs = {
    'name': 'ramstk',
    'version': '0.16.3',
    'description': 'A tool to manage RAMS data and analyses.',
    'long_description': '# The RAMS ToolKit (RAMSTK)\n> A ToolKit for **R**eliability, **A**vailability, **M**aintainability, and\n> **S**afety (RAMS) analyses.\n\n<table>\n    <tr>\n        <th>Tests</th>\n        <td>\n        <img alt="GitHub Workflow Status" src="https://img.shields.io/github/workflow/status/ReliaQualAssociates/ramstk/RAMSTK%20Test%20Suite?label=Build%20%26%20Test">\n        <a href="https://codecov.io/gh/ReliaQualAssociates/ramstk"><img src="https://codecov.io/gh/ReliaQualAssociates/ramstk/branch/master/graph/badge.svg?token=sFOa7EjZAg"/></a>\n        <a href=\'https://coveralls.io/github/ReliaQualAssociates/ramstk?branch=master\'><img src=\'https://coveralls.io/repos/github/ReliaQualAssociates/ramstk/badge.svg?branch=master\' alt=\'Coverage Status\' /></a>\n    </td>\n    </tr>\n    <tr>\n        <th>Quality</th>\n        <td>\n            <a href="https://www.codefactor.io/repository/github/reliaqualassociates/ramstk"><img src="https://www.codefactor.io/repository/github/reliaqualassociates/ramstk/badge" alt="CodeFactor" /></a>\n            <img alt="Quality Gate" src="https://sonarcloud.io/api/project_badges/measure?project=ReliaQualAssociates_ramstk&metric=alert_status">\n        </td>\n    </tr>\n    <tr>\n        <th>Packages</th>\n        <td>\n            <img alt="GitHub release (latest SemVer including pre-releases)" src="https://img.shields.io/github/v/release/ReliaQualAssociates/ramstk?include_prereleases&label=GitHub%20Release">\n            <img alt="PyPI" src="https://img.shields.io/pypi/v/ramstk?label=PyPi%20Release">\n        </td>\n    </tr>\n</table>\n\n## 🚩 Table of Contents\n- [Features](#-features)\n- [Installing](#-installing)\n    - [Prerequisites](#prerequisites)\n    - [Download](#download)\n    - [Running the Tests](#running-the-tests)\n- [Usage](#-usage)\n- [Documentation](#documentation)\n- [Contributing](#-contributing)\n- [Authors](#-authors)\n- [License](#-license)\n- [Similar Products](#similar-products)\n\n## Disclaimer\n\nRAMSTK attempts to use [Semantic Versioning](https://semver.org/) 2.0.0.  Per\nspec item 4, major version 0 is for initial development and anything may\nchange at any time.  That is certainly the case for RAMSTK!  Because RAMSTK\nis a one developer show, there is no active develop branch at the moment.\n This may change after release of 1.0.0.  Until then, tagged releases can be\nused, but the `latest` tag may not work and may not be backwards-compatible.\n While major version is at 0, breaking changes will be reflected in bumps to\nthe minor version number.  That is, version 0.15.0 is not compatible with\nversion 0.14.0.\n\n## 🎨&nbsp; Features\n\nRAMSTK is built on the concept of modules where a module is a collection of\nrelated information and/or analyses pertinent to system development.  The\nmodules currently included in RAMSTK are:\n\n* Revision Module\n  - Usage profile\n* Function Module\n  - Functional decomposition\n  - Hazards analysis\n  - Failure definitions\n* Requirements Module\n  - Stakeholder input prioritization\n  - Requirement development\n  - Analysis of requirement for clarity, completeness, consistency, and verifiability\n* Hardware Module\n  - Reliability allocation\n      - Equal apportionment\n      - AGREE apportionment\n      - ARINC apportionment\n      - Feasibility of Objectives\n  - Hardware reliability predictions using various methods\n      - Similar items analysis\n      - MIL-HDBK-217F parts count\n      - MIL-HDBK-217F parts stress\n  - FMEA/FMECA\n      - RPN\n      - MIL-STD-1629A, Task 102 Criticality Analysis\n  - Physics of failure analysis\n* Validation & Verification Module\n  - Task description\n  - Task acceptance value(s)\n  - Task time\n  - Task cost\n  - Overall validation plan time/cost estimates\n\n## 💾&nbsp; Installing\n\nRAMSTK uses [postgresql](https://www.postgresql.org/) for its database\nengine.  You\'ll need to have a user with read/write access to a postgresql\nserver to use RAMSTK.  Instructions for setting up the postgresql servers and\ncreating users with the appropriate permissions can be found in the project\n[Wiki](https://github.com/ReliaQualAssociates/ramstk/wiki).\n\n### Download and Install\n\nSince RAMSTK is still a version 0 product, it\'s highly recommended that you\ninstall in a virtual environment.  The instructions below presume you will\nbe installing in a virtual environment and system-wide Python packages that\nRAMSTK depends on will be unavailable.  That being the case, you will need\nvarious system development packages available via your operating system\'s\npackage manager to install RAMSTK.\n\nOnce you have installed any missing development file packages using your\noperating system\'s package manager, download the \\<version> of RAMSTK\nsource from GitHub you wish to install.\n\n```shell\n$ wget https://github.com/ReliaQualAssociates/ramstk/archive/v<version>.tar.gz\n$ tar -xf v<version>.tar.gz\n$ cd ramstk-<version>\n```\n\nThe other option for obtaining the RAMSTK source code is to clone the\nrepository.\n\n```shell\n$ git clone https://github.com/ReliaQualAssociates/ramstk.git ramstk.git\n$ cd ramstk.git\n```\n\nCreate and activate a virtual environment however you are acustomed to.\nOne approach is to use pyenv and poetry.  Using pyenv isn\'t necessary\nunless you want to install and use a Python version other than that\nprovided by your operating system.\n\n```shell\n$ pyenv install 3.8.7\n$ poetry env use ~/.pyenv/shims/python3.8\n$ poetry shell\n```\n\nThis will install Python-3.8.7 and tell poetry to use the Python interpreter\nyou just installed.  Finally, poetry will create, if needed, and activate\nthe virtual environment using Python-3.8.7 as the interpreter.\n\nNow that the virtual environment is activated, you can install the\nnecessary RAMSTK dependencies and RAMSTK itself.  Omitting the PREFIX\nvariable will cause RAMSTK to install to /usr/local by default.\n\n```shell\n$ make depends\n$ make PREFIX=$VIRTUAL_ENV install\n```\n\nWhen upgrading RAMSTK, you can simply:\n\n```shell\n$ pip install -U ramstk\n```\n\nThis will only install the latest RAMSTK version from PyPi and will leave\nconfiguration, data, and icon files untouched.  If you cloned the RAMSTK\nrepository, you can also use the Makefile:\n\n```shell\n$ git switch master\n$ git pull\n$ make install.dev\n```\n\n### Development Dependencies\n\nWe use [poetry](https://github.com/python-poetry/poetry) to manage the\ndependencies for developing RAMSTK.  Using the Makefile, install as follows:\n\n```shell\n$ make depends\n```\n\nThis should get all the needed development and runtime requirements installed\nif they\'re not already.\n\n### Running the Tests\n\nTo run the entire test suite for RAMSTK after installing, simply execute:\n\n```shell\n$ make test\n```\n\nTo run the test suite with coverage, execute:\n\n```shell\n$ make coverage\n$ make coverage.report\n```\n\nTo run specific tests or groups of tests, use pytest:\n\n```shell\n$ pytest -m integration tests/modules/test_allocation.py\n$ pytest -m unit tests/analyses/prediction\n```\n\n## 🔨&nbsp; Usage\n\nAfter installing RAMSTK, it can be launched from a terminal emulator:\n\n```\n$ ramstk\n```\n\nThis is a good option if you need to file an issue as the output should be\nincluded in your report.  RAMSTK also installs a *.desktop file and can be\nfound where ever applications in the category Math or Science are listed.\nIf you\'ve installed in a virtual environment or other non-standard location,\nthis *.desktop file may not be found.\n\nSee the User Guide for the latest usage instructions.\n\n## Documentation\n\nDocumentation for RAMSTK is built and included as release assets.  For each\nrelease, you will find a pdf and html implementation of the User Guide.  For\neach minor and major version release, you will also find a pdf and html\nimplementation of the Developer\'s Guide.\n\n## 💬&nbsp; Contributing\n\nPlease read [CONTRIBUTING.md](https://github.com/ReliaQualAssociates/ramstk/tree/develop/docs/CONTRIBUTING.md) for details on our code of conduct, and the process for submitting pull requests to us.\n\nAlso read [DEVELOPMENT_ENV.md](https://github.com/ReliaQualAssociates/ramstk/tree/develop/docs/DEVELOPMENT_ENV.md) for instructions on setting up a development environment to work on and test RAMSTK.\n\n## 🍞&nbsp; Authors\n\n* **Doyle \'weibullguy\' Rowland** - *Initial work* - [weibullguy](https://github.com/weibullguy)\n\n## 📜&nbsp; License\nThis project is licensed under the BSD-3-Clause License - see the [LICENSE](https://github.com/ReliaQualAssociates/ramstk/blob/develop/LICENSE) file for details.\n\nRAMSTK is also registered with the United States Copyright Office under\nregistration number TXu 1-896-035 because I have an attorney and attorneys\nlike to file paperwork for $300/hour.\n\n## Similar Products\n\nThe following are commercially available products that perform RAMS\nanalyses.  We are not endorsing any of them; they are all fine products and\nmay be a better fit for you or your organization depending on your needs\nand budget.  Obviously, we would prefer you use RAMSTK.\n\n* [PTC Windchill Quality](https://www.ptc.com/en/products/plm/capabilities/quality)\n* [ReliaSoft Synthesis](https://www.reliasoft.com/products)\n',
    'author': "Doyle 'weibullguy' Rowland",
    'author_email': 'doyle.rowland@reliaqual.com',
    'maintainer': "Doyle 'weibullguy' Rowland",
    'maintainer_email': 'doyle.rowland@reliaqual.com',
    'url': 'https://github.com/ReliaQualAssociates/ramstk',
    'package_dir': package_dir,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.6.2,<4.0.0',
}


setup(**setup_kwargs)



# Standard Library Imports
import gettext
from typing import Dict, Tuple, Union

# RAMSTK Package Imports
from ramstk.configuration import RAMSTKSiteConfiguration as RAMSTKSiteConfiguration
from ramstk.configuration import RAMSTKUserConfiguration as RAMSTKUserConfiguration
from ramstk.db import BaseDatabase as BaseDatabase
from ramstk.db import do_create_program_db as do_create_program_db
from ramstk.models.dbrecords import RAMSTKCategoryRecord as RAMSTKCategoryRecord
from ramstk.models.dbrecords import RAMSTKFailureModeRecord as RAMSTKFailureModeRecord
from ramstk.models.dbrecords import RAMSTKGroupRecord as RAMSTKGroupRecord
from ramstk.models.dbrecords import RAMSTKHazardsRecord as RAMSTKHazardsRecord
from ramstk.models.dbrecords import RAMSTKLoadHistoryRecord as RAMSTKLoadHistoryRecord
from ramstk.models.dbrecords import RAMSTKManufacturerRecord as RAMSTKManufacturerRecord
from ramstk.models.dbrecords import RAMSTKMeasurementRecord as RAMSTKMeasurementRecord
from ramstk.models.dbrecords import RAMSTKMethodRecord as RAMSTKMethodRecord
from ramstk.models.dbrecords import RAMSTKModelRecord as RAMSTKModelRecord
from ramstk.models.dbrecords import RAMSTKRPNRecord as RAMSTKRPNRecord
from ramstk.models.dbrecords import RAMSTKSiteInfoRecord as RAMSTKSiteInfoRecord
from ramstk.models.dbrecords import RAMSTKStakeholdersRecord as RAMSTKStakeholdersRecord
from ramstk.models.dbrecords import RAMSTKStatusRecord as RAMSTKStatusRecord
from ramstk.models.dbrecords import RAMSTKSubCategoryRecord as RAMSTKSubCategoryRecord
from ramstk.models.dbrecords import RAMSTKTypeRecord as RAMSTKTypeRecord
from ramstk.models.dbrecords import RAMSTKUserRecord as RAMSTKUserRecord

_ = gettext.gettext

class RAMSTKCommonDB:
    dic_tables: Dict[str, object]
    site_configuration: RAMSTKSiteConfiguration
    common_dao: BaseDatabase
    def __init__(self) -> None: ...
    def do_create_common(
        self, common_db: BaseDatabase, database: Dict[str, str], license_file: str
    ) -> None: ...
    def do_add_administrator(self) -> None: ...
    def do_load_site_info(self, license_file: str) -> None: ...
    def do_load_site_variables(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_action_categories(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_action_status(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_affinity_groups(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_damage_models(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_detection_methods(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_failure_modes(
        self, category_id: int, subcategory_id: int
    ) -> Dict[int, Union[float, str]]: ...
    def _do_load_hardware_variables(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_hazards(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_incident_categories(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_incident_status(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_incident_types(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_load_history(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_manufacturers(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_measureable_parameters(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_measurement_units(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_requirement_types(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_rpn_detection(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_rpn_occurrence(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_rpn_severity(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_stakeholders(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_severity(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    @staticmethod
    def _do_load_stress_limits(
        record: RAMSTKCategoryRecord,
    ) -> Tuple[
        float, float, float, float, float, float, float, float, float, float
    ]: ...
    def _do_load_users(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_validation_types(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
    def _do_load_workgroups(
        self, user_configuration: RAMSTKUserConfiguration
    ) -> RAMSTKUserConfiguration: ...
